function [uz,urho]=mogi_sphere(p,a,d,mu,nu,rho)
% 
% p     pressure in sphere
% d 	depth to center of source
% nu    Poisson's ratio
% rho   radial horizontal distance from source
% 
% uz 	vertical displacement at surface
% urho  horizontal radial displacement 

front = ((1-nu)*p*a^3)/mu;

bot = (rho.^2 + d.^2).^(3/2);

uz = front*d./bot;

urho = front*rho./bot;



